==> haskell-bz2-1.0.1.0-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bz2
version:              1.0.1.0
visibility:           public
id:                   bz2-1.0.1.0-CpkRCxUiit72odwJuxnQeh
key:                  bz2-1.0.1.0-CpkRCxUiit72odwJuxnQeh
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  44452fdf139dd44a0d638192db1ec5a4
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Common Codec.Compression.BZip.Unpack
    Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bz2-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bz2-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.0-CpkRCxUiit72odwJuxnQeh
extra-libraries:      bz2
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bz2-1.0.1.0-158-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bz2.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bz2
version:              1.0.1.0
visibility:           public
id:                   bz2-1.0.1.0-GT1Ql4gWlUY3KwB9cQuXZr
key:                  bz2-1.0.1.0-GT1Ql4gWlUY3KwB9cQuXZr
license:              BSD-3-Clause
copyright:            Copyright: (c) 2020 Vanessa McHale
maintainer:           vamchale@gmail.com
author:               Vanessa McHale
synopsis:             Bindings to libbz2
description:          High-level bindings to libbz2 via ByteString
category:             Compression
abi:                  ee9ddf15c9dcff5b0993918d4c127697
exposed:              True
exposed-modules:      Codec.Compression.BZip
hidden-modules:
    Codec.Compression.BZip.Foreign.Common
    Codec.Compression.BZip.Foreign.Compress
    Codec.Compression.BZip.Foreign.Decompress
    Codec.Compression.BZip.Common Codec.Compression.BZip.Unpack
    Codec.Compression.BZip.Pack

import-dirs:          /usr/lib/ghc-9.0.2/site-local/bz2-1.0.1.0
library-dirs:         /usr/lib/ghc-9.0.2/site-local/bz2-1.0.1.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bz2
hs-libraries:         HSbz2-1.0.1.0-GT1Ql4gWlUY3KwB9cQuXZr
extra-libraries:      bz2
depends:              base-4.15.1.0 bytestring-0.10.12.1
haddock-interfaces:   /usr/share/doc/haskell-bz2/html/bz2.haddock
haddock-html:         /usr/share/doc/haskell-bz2/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
